@@ -9,6 +9,7 @@ sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 import json
 import pymongo
 import pandas as pd
+import numpy as np
 
 from database.db_mongo import MongoDatabase
 from database.db_neo4j import Neo4jDatabase
@@ -115,15 +116,19 @@ class dataframeGen(object):
         food_df['Category'] = 'food'
         not_food_df['Category'] = 'not food'
 
-        return pd.concat([food_df.copy(), not_food_df.copy()])
+        return pd.concat([food_df.copy(), not_food_df.copy()], sort=True)
 
     def save_dataframe(self, dataframe, df_name):
-        payload = json.loads(dataframe.to_json(orient='records'))
+        created = pd.datetime.now()
 
-        self.mongo_conn.db[df_name].insert_one({
-            'df': payload,
-            'created': pd.datetime.now()
-        })
+        for _, df in dataframe.groupby(np.arange(len(dataframe)) // 10000):
+
+            payload = json.loads(df.to_json(orient='records'))
+            
+            self.mongo_conn.db[df_name].insert_one({
+                'df': payload,
+                'created': created
+            })
 
     def close_mongo_connection(self):
         self.mongo.close_connection()
