@@ -2,6 +2,7 @@ import pymongo
 import sys
 import ssl
 
+import pandas as pd
 import database.db_credentials as db
 
 class MongoDatabase(object):
@@ -25,3 +26,8 @@ class MongoDatabase(object):
 
         sys.stdout.flush()
     
+    def get_dataframe_from_mongo(self, mongo_conn, collection):
+        products_df = mongo_conn.db[collection].find(
+            {}).sort('created', pymongo.DESCENDING)
+
+        return pd.DataFrame(products_df[0]['df']) if products_df else ''
