@@ -1,8 +1,8 @@
-import sys
 from neo4j import GraphDatabase
 
 import database.db_credentials as db
 
+
 class Neo4jDatabase(object):
 
     def __init__(self, environment):
@@ -25,11 +25,11 @@ class Neo4jDatabase(object):
         return result
 
     def execute_query(self, tx, query, params):
-        if params != None:
+        if params is not None:
             query_result = tx.run(query, params)
         else:
             query_result = tx.run(query)
 
         response = [result for result in query_result]
 
-        return response
\ No newline at end of file
+        return response
