@@ -1,19 +1,15 @@
 
-from datetime import datetime
 import sys
 import os 
 from sys import argv
 
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 
-import json
-import pymongo
-import pandas as pd
-
 from database.db_mongo import MongoDatabase
 from database.db_neo4j import Neo4jDatabase
 import utils.utils as utils
 
+
 class BI(object):
 
     def __init__(self, environment):
@@ -24,7 +20,7 @@ class BI(object):
     def process_bi(self):
         self.open_database_connections()
 
-        self.products_df = self.utils.get_dataframe_from_mongo(self.mongo_conn, 'food_df')
+        self.products_df = self.mongo.get_dataframe_from_mongo(self.mongo_conn, 'food_df')
 
         self.close_mongo_connection()
 
