@@ -1,13 +1,8 @@
 import boto3
-import os
-import sys
-from sys import argv
+
 
 class DeployModel(object):
 
-    def __init__(self):
-        pass
-
     def deploy_to_s3(self, model_version):
         s3_resource = boto3.resource('s3')
         bucket_name = 'category-model' if 'category_model' in model_version.split('/') else 'food-model'
